jaclearn.embedding.word\_embedding
==================================

.. automodule:: jaclearn.embedding.word_embedding

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      load
      load_word_index
      map
      map_sequence
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: load

.. autofunction:: load_word_index

.. autofunction:: map

.. autofunction:: map_sequence


